@@ -44,7 +44,7 @@ import org.w3c.dom.Node;
  * done by calling {@link Init#init} which should be done in any static block
  * of the files of this library. We ensure that this call is only executed once.
  *
- * @author $Author: mullan $
+ * @author $Author: coheigea $
  */
 public class Init {
 
@@ -145,7 +145,7 @@ public class Init {
                 }
             }
 			for (Node el=config.getFirstChild();el!=null;el=el.getNextSibling()) {
-                if (!(el instanceof Element)) {
+                if (el == null || Node.ELEMENT_NODE != el.getNodeType()) {
                 	continue;
                 }
                 String tag=el.getLocalName();
