@@ -21,6 +21,8 @@ package org.apache.xml.security.keys;
 import java.security.PublicKey;
 import java.security.cert.X509Certificate;
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Iterator;
 import java.util.List;
 
 import javax.crypto.SecretKey;
@@ -94,9 +96,11 @@ public class KeyInfo extends SignatureElementProxy {
     List x509Datas=null;
     List encryptedKeys=null;
     
-    static List nullList=new ArrayList();
+    static final List nullList;
     static {
-    	nullList.add(null);
+    	List list = new ArrayList();
+        list.add(null);
+        nullList = Collections.unmodifiableList(list);
     }
 
    /**
@@ -120,7 +124,7 @@ public class KeyInfo extends SignatureElementProxy {
     */
    public KeyInfo(Element element, String BaseURI) throws XMLSecurityException {
       super(element, BaseURI);
-      _storageResolvers.add(null);
+     // _storageResolvers.add(null);
 
    }
 
@@ -131,7 +135,7 @@ public class KeyInfo extends SignatureElementProxy {
     */
    public void setId(String Id) {
 
-      if ((this._state == MODE_SIGN) && (Id != null)) {
+      if ((Id != null)) {
          this._constructionElement.setAttributeNS(null, Constants._ATT_ID, Id);
          IdResolver.registerElementById(this._constructionElement, Id);
       }
@@ -162,10 +166,8 @@ public class KeyInfo extends SignatureElementProxy {
     */
    public void add(KeyName keyname) {
 
-      if (this._state == MODE_SIGN) {
          this._constructionElement.appendChild(keyname.getElement());
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
    /**
@@ -219,11 +221,8 @@ public class KeyInfo extends SignatureElementProxy {
     * @param keyvalue
     */
    public void add(KeyValue keyvalue) {
-
-      if (this._state == MODE_SIGN) {
          this._constructionElement.appendChild(keyvalue.getElement());
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
    /**
@@ -241,11 +240,8 @@ public class KeyInfo extends SignatureElementProxy {
     * @param mgmtdata
     */
    public void add(MgmtData mgmtdata) {
-
-      if (this._state == MODE_SIGN) {
          this._constructionElement.appendChild(mgmtdata.getElement());
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
    /**
@@ -254,11 +250,8 @@ public class KeyInfo extends SignatureElementProxy {
     * @param pgpdata
     */
    public void add(PGPData pgpdata) {
-
-      if (this._state == MODE_SIGN) {
          this._constructionElement.appendChild(pgpdata.getElement());
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
    /**
@@ -279,11 +272,8 @@ public class KeyInfo extends SignatureElementProxy {
     * @param retrievalmethod
     */
    public void add(RetrievalMethod retrievalmethod) {
-
-      if (this._state == MODE_SIGN) {
          this._constructionElement.appendChild(retrievalmethod.getElement());
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
    /**
@@ -292,11 +282,8 @@ public class KeyInfo extends SignatureElementProxy {
     * @param spkidata
     */
    public void add(SPKIData spkidata) {
-
-      if (this._state == MODE_SIGN) {
          this._constructionElement.appendChild(spkidata.getElement());
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
    /**
@@ -305,14 +292,11 @@ public class KeyInfo extends SignatureElementProxy {
     * @param x509data
     */
    public void add(X509Data x509data) {
-
-      if (this._state == MODE_SIGN) {
     	  if (x509Datas==null)
     		  x509Datas=new ArrayList();
     	  x509Datas.add(x509data);
          this._constructionElement.appendChild(x509data.getElement());
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
 	/**
@@ -324,15 +308,11 @@ public class KeyInfo extends SignatureElementProxy {
 
 	public void add(EncryptedKey encryptedKey) 
 		throws XMLEncryptionException {
-
-		if (this._state == MODE_SIGN) {
 			if (encryptedKeys==null)
 				encryptedKeys=new ArrayList();
 			encryptedKeys.add(encryptedKey);
 			XMLCipher cipher = XMLCipher.getInstance();
 			this._constructionElement.appendChild(cipher.martial(encryptedKey));
-		}
-
 	}
 
    /**
@@ -341,11 +321,8 @@ public class KeyInfo extends SignatureElementProxy {
     * @param element
     */
    public void addUnknownElement(Element element) {
-
-      if (this._state == MODE_SIGN) {
          this._constructionElement.appendChild(element);
          XMLUtils.addReturnToElement(this._constructionElement);
-      }
    }
 
    /**
@@ -747,12 +724,13 @@ public class KeyInfo extends SignatureElementProxy {
    PublicKey getPublicKeyFromStaticResolvers() throws KeyResolverException {
 	  int length=KeyResolver.length();
 	  int storageLength=this._storageResolvers.size();
+	  Iterator it= KeyResolver.iterator();
       for (int i = 0; i < length; i++) {
-         KeyResolverSpi keyResolver = KeyResolver.item(i);
+         KeyResolverSpi keyResolver = (KeyResolverSpi) it.next();
          Node currentChild=this._constructionElement.getFirstChild();
          String uri= this.getBaseURI();
          while (currentChild!=null)      {       
-            if (currentChild.getNodeType() == Node.ELEMENT_NODE) {               
+            if (currentChild.getNodeType() == Node.ELEMENT_NODE) {          	  
                   for (int k = 0; k < storageLength; k++) {
                      StorageResolver storage =
                         (StorageResolver) this._storageResolvers.get(k);
@@ -763,7 +741,7 @@ public class KeyInfo extends SignatureElementProxy {
                                                         storage);
 
                      if (pk != null) {
-                    	 KeyResolver.hit(i);
+                    	 KeyResolver.hit(it);
                          return pk;
                      }                     
                   }                              
@@ -862,12 +840,13 @@ public class KeyInfo extends SignatureElementProxy {
                 + KeyResolver.length() + " resolvers");
       String uri=this.getBaseURI();
       int length= KeyResolver.length();
-      int storageLength=this._storageResolvers.size();            
+      int storageLength=this._storageResolvers.size();   
+      Iterator it = KeyResolver.iterator();
       for (int i = 0; i <length; i++) {
-         KeyResolverSpi keyResolver = KeyResolver.item(i);
+         KeyResolverSpi keyResolver = (KeyResolverSpi) it.next();
          X509Certificate cert= applyCurrentResolver(uri, storageLength, keyResolver);
          if (cert!=null) {
-        	 KeyResolver.hit(i);
+        	 KeyResolver.hit(it);
         	 return cert;
          }
       }
@@ -961,8 +940,9 @@ public class KeyInfo extends SignatureElementProxy {
    SecretKey getSecretKeyFromStaticResolvers() throws KeyResolverException {
 	  final int length=KeyResolver.length();
 	  int storageLength=this._storageResolvers.size();
+	  Iterator it = KeyResolver.iterator();
       for (int i = 0; i < length; i++) {
-         KeyResolverSpi keyResolver = KeyResolver.item(i);
+         KeyResolverSpi keyResolver = (KeyResolverSpi) it.next();
 
          Node currentChild=this._constructionElement.getFirstChild();
          String uri=this.getBaseURI();
