@@ -35,7 +35,7 @@ import org.w3c.dom.Text;
  * This is the base class to all Objects which have a direct 1:1 mapping to an
  * Element in a particular namespace.
  *
- * @author $Author: mullan $
+ * @author $Author: coheigea $
  */
 public abstract class ElementProxy {
 
@@ -514,6 +514,9 @@ public abstract class ElementProxy {
    	if (Constants.SignatureSpecNS.equals(namespace)) {
    	    XMLUtils.dsPrefix=prefix;
    	}
+   	if (EncryptionConstants.EncryptionSpecNS.equals(namespace)) {
+   	    XMLUtils.xencPrefix=prefix;
+   	}
         ElementProxy._prefixMappings.put(namespace, prefix.intern());
 	if (prefix.length() == 0) {
             ElementProxy._prefixMappingsBindings.put(namespace, "xmlns");
