@@ -21,6 +21,8 @@ package org.apache.xml.security.utils;
 
 import java.io.IOException;
 import java.io.OutputStream;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -47,15 +49,13 @@ import org.w3c.dom.Text;
  */
 public class XMLUtils {
 
-   private static boolean ignoreLineBreaks = false;
-   static {
-      try {
-         ignoreLineBreaks = Boolean.getBoolean
-	    ("org.apache.xml.security.ignoreLineBreaks");
-      } catch (Exception e) {
-         // ignore exceptions
-      }
-   }
+   private static boolean ignoreLineBreaks = ((Boolean)
+      AccessController.doPrivileged(new PrivilegedAction() {
+         public Object run() {
+            return Boolean.valueOf(Boolean.getBoolean
+	       ("org.apache.xml.security.ignoreLineBreaks"));
+         }
+      })).booleanValue();
 	
    /**
     * Constructor XMLUtils
@@ -256,6 +256,35 @@ public class XMLUtils {
       return doc.createElementNS(Constants.SignatureSpecNS, namePrefix);
    }
 
+   static  String xencPrefix=null;
+   /**
+    * Creates an Element in the XML Encryption specification namespace.
+    *
+    * @param doc the factory Document
+    * @param elementName the local name of the Element
+    * @return the Element
+    */
+   public static Element createElementInEncryptionSpace(Document doc,
+           String elementName) {
+
+      if (doc == null) {
+         throw new RuntimeException("Document is null");
+      }
+     
+      if ((xencPrefix == null) || (xencPrefix.length() == 0)) {
+         return doc.createElementNS(EncryptionConstants.EncryptionSpecNS, elementName);
+      } 
+      String namePrefix=(String) namePrefixes.get(elementName);
+      if (namePrefix==null) {
+    	  StringBuffer tag=new StringBuffer(xencPrefix);
+    	  tag.append(':');
+    	  tag.append(elementName);
+    	  namePrefix=tag.toString();
+    	  namePrefixes.put(elementName,namePrefix);
+      }
+      return doc.createElementNS(EncryptionConstants.EncryptionSpecNS, namePrefix);
+   }
+
    /**
     * Returns true if the element is in XML Signature namespace and the local
     * name equals the supplied one.
@@ -339,6 +368,28 @@ public class XMLUtils {
                                        + (npe == null ? "" : npe.getMessage()) + "\"");
     }
     
+    /**
+     * Method createDSctx
+     *
+     * @param doc
+     * @param prefix
+     * @param namespace
+     * @return the element.
+     */
+    public static Element createDSctx(Document doc, String prefix,
+                                      String namespace) {
+
+       if ((prefix == null) || (prefix.trim().length() == 0)) {
+          throw new IllegalArgumentException("You must supply a prefix");
+       }
+
+       Element ctx = doc.createElementNS(null, "namespaceContext");
+
+       ctx.setAttributeNS(Constants.NamespaceSpecNS, "xmlns:" + prefix.trim(),
+                          namespace);
+
+       return ctx;
+    }
 
    /**
     * Method addReturnToElement
