@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 The Apache Software Foundation.
+ * Copyright 2005-2009 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@
  * ===========================================================================
  */
 /*
- * $Id: DOMXMLSignature.java 656799 2008-05-15 19:23:15Z mullan $
+ * $Id: DOMXMLSignature.java 793943 2009-07-14 15:33:19Z coheigea $
  */
 package org.jcp.xml.dsig.internal.dom;
 
@@ -36,7 +36,6 @@ import javax.xml.crypto.dsig.dom.DOMSignContext;
 import javax.xml.crypto.dsig.dom.DOMValidateContext;
 import javax.xml.crypto.dsig.keyinfo.KeyInfo;
 
-import java.io.*;
 import java.security.InvalidKeyException;
 import java.security.Key;
 import java.security.Provider;
@@ -392,9 +391,6 @@ public final class DOMXMLSignature extends DOMStructure
             throw new XMLSignatureException(ike);
 	}
 
-	if (log.isLoggable(Level.FINE)) {
-            log.log(Level.FINE, "SignatureValue = " + val);        
-	}
 	((DOMSignatureValue) sv).setValue(val);
 
         this.localSigElem = sigElem;   
