@@ -1,5 +1,5 @@
 /*
- * Copyright 2006 The Apache Software Foundation.
+ * Copyright 2006-2009 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -27,7 +27,6 @@ import java.security.PublicKey;
 import java.security.Security;
 import java.security.cert.Certificate;
 import java.security.cert.CertificateFactory;
-import java.security.cert.X509Certificate;
 import java.security.cert.X509CRL;
 import java.util.*;
 import javax.xml.parsers.*;
@@ -93,8 +92,10 @@ public class CreateBaltimore23Test extends TestCase {
 
 	// get key & self-signed certificate from keystore
 	String fs = System.getProperty("file.separator");
+	String base = System.getProperty("basedir") == null ? "./": System.getProperty("basedir");
+
 	FileInputStream fis = new FileInputStream
-	    (System.getProperty("basedir") + fs + "data" + fs + "test.jks");
+	    (base + fs + "data" + fs + "test.jks");
 	ks = KeyStore.getInstance("JKS");
 	ks.load(fis, "changeit".toCharArray());
 	signingKey = ks.getKey("mullan", "changeit".toCharArray());
@@ -163,8 +164,14 @@ public class CreateBaltimore23Test extends TestCase {
 	throws Exception {
 	SignatureMethod hmacSha1 = fac.newSignatureMethod
 	    (SignatureMethod.HMAC_SHA1, new HMACParameterSpec(40));
-        test_create_signature_enveloping(hmacSha1, null,
-	    TestUtils.getSecretKey("secret".getBytes("ASCII")), sks, false);
+        try {
+            test_create_signature_enveloping(hmacSha1, null,
+	        TestUtils.getSecretKey("secret".getBytes("ASCII")), sks, false);
+            fail("Expected HMACOutputLength Exception");
+        } catch (XMLSignatureException xse) {
+            System.out.println(xse.getMessage());
+            // pass
+        }
     }
 
     public void test_create_signature_enveloping_hmac_sha1()
@@ -295,7 +302,7 @@ public class CreateBaltimore23Test extends TestCase {
           + "	   id('notaries')) =				 " + "\n"
           + " count(ancestor-or-self::node())			 " + "\n";
 
-	XPathFilterParameterSpec xfp = new XPathFilterParameterSpec(expr,
+	new XPathFilterParameterSpec(expr,
 	    Collections.singletonMap("dsig", XMLSignature.XMLNS));
 //        refs.add(fac.newReference("", sha1, Collections.singletonList
 //	    (fac.newTransform(Transform.XPATH, xfp)),
